Module span

Module span 

Structs

Loc
A source location. line is 1-based, col is a 0-based character column, byte is the byte offset into the source.
Span
A half-open source range [start, end).

Functions

floor_char_boundary
The largest char boundary at or below byte, clamped to src.len().